@@ -1,5 +1,5 @@
 package Net::Async::Statsd::Server;
-$Net::Async::Statsd::Server::VERSION = '0.002';
+$Net::Async::Statsd::Server::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Net::Async::Statsd::Server - asynchronous server for Etsy's statsd protocol
 
 =head1 VERSION
 
-Version 0.002
+Version 0.003
 
 =head1 SYNOPSIS
 
@@ -217,7 +217,7 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
